summaryrefslogtreecommitdiffstats
path: root/templates/annotated/menuapp3.py
diff options
context:
space:
mode:
Diffstat (limited to 'templates/annotated/menuapp3.py')
-rw-r--r--templates/annotated/menuapp3.py14
1 files changed, 7 insertions, 7 deletions
diff --git a/templates/annotated/menuapp3.py b/templates/annotated/menuapp3.py
index 59b0a6a..9ac414d 100644
--- a/templates/annotated/menuapp3.py
+++ b/templates/annotated/menuapp3.py
@@ -44,15 +44,15 @@ import sys
from qt import TQPopupMenu, SIGNAL
from tdecore import TDEApplication, TDECmdLineArgs, TDEAboutData, i18n
-from tdeui import KMainWindow, KMessageBox, KStdAction, KAction, KActionCollection
+from tdeui import TDEMainWindow, KMessageBox, KStdAction, TDEAction, TDEActionCollection
STATUSBAR_LEFT = 1
STATUSBAR_MIDDLE = 2
STATUSBAR_RIGHT = 3
-class MainWin (KMainWindow):
+class MainWin (TDEMainWindow):
def __init__ (self, *args):
- apply (KMainWindow.__init__, (self,) + args)
+ apply (TDEMainWindow.__init__, (self,) + args)
# Create actions that correspond to those in the XML file
self.initActions ()
@@ -94,7 +94,7 @@ class MainWin (KMainWindow):
# if you defined the KStdActions as below. In fact, you can't override
# this behavior using KStdActions - if you want menus to be "non-standard"
# TDE menus (eg 'Cut' in the 'File' menu), you'll need to create your
# actions from KAction instead of KStdAction. Obviously it makes more
# sense to use the mechanism provided to produce consistent menus and
# toolbars. You can "unplug" items if, for example, you don't want them
# in the toolBar.
@@ -118,11 +118,11 @@ class MainWin (KMainWindow):
self.findNextAction = KStdAction.findNext (self.slotFindNext, self.actionCollection ())
self.replaceAction = KStdAction.replace (self.slotReplace, self.actionCollection ())
# For ANYTHING constructed from KAction or its descendants (KActionMenu, KActionSeparator,
# KFontAction, etc) you MUST provide the self.actionCollection () parent and an object
# name ("specialActionName") or the XMLGUI mechanism will not be able to locate the
# action. XMLGUI finds the action via its member name value, NOT via its variable name.
- self.specialAction = KAction (i18n ("Special"), 0, self.slotSpecial, self.actionCollection (), "specialActionName")
+ self.specialAction = TDEAction (i18n ("Special"), 0, self.slotSpecial, self.actionCollection (), "specialActionName")
def initStatusBar (self):
self.statusBar ().insertItem ("", STATUSBAR_LEFT, 1000, True)
@@ -94,7 +94,7 @@ class MainWin (KMainWindow):
# this behavior using KStdActions - if you want menus to be "non-standard"
# TDE menus (eg 'Cut' in the 'File' menu), you'll need to create your
- # actions from KAction instead of KStdAction. Obviously it makes more
+ # actions from TDEAction instead of KStdAction. Obviously it makes more
# sense to use the mechanism provided to produce consistent menus and
# toolbars. You can "unplug" items if, for example, you don't want them
@@ -118,11 +118,11 @@ class MainWin (KMainWindow):
self.findNextAction = KStdAction.findNext (self.slotFindNext, self.actionCollection ())
self.replaceAction = KStdAction.replace (self.slotReplace, self.actionCollection ())
- # For ANYTHING constructed from KAction or its descendants (KActionMenu, KActionSeparator,
- # KFontAction, etc) you MUST provide the self.actionCollection () parent and an object
+ # For ANYTHING constructed from TDEAction or its descendants (TDEActionMenu, TDEActionSeparator,
+ # TDEFontAction, etc) you MUST provide the self.actionCollection () parent and an object
# name ("specialActionName") or the XMLGUI mechanism will not be able to locate the
# action. XMLGUI finds the action via its member name value, NOT via its variable name.